Learn R Programming

iNEXT.4steps (version 1.0.1)

Data_spider: Spider abundance data

Description

These data were sampled in a mountain forest ecosystem in the Bavarian Forest National Park, Germany (Thorn et al. 2016, 2017). A total of 12 experimental plots were established in "closed forest" stands (6 plots) and "open forest" stands with naturally occurring gaps and edges (6 plots) to assess the effects of microclimate on communities of epigeal (ground-dwelling) spiders.
Epigeal spiders were sampled over three years with four pitfall traps in each plot, yielding a total of 3171 individuals belonging to 85 species recorded in the pooled habitat. In the open forest, there were 1760 individuals representing 74 species, whereas in the closed forest, there were 1411 individuals representing 44 species.

Usage

data("Data_spider")

Arguments

Format

Woody_plants is a species-by-assemblages data.frame with 85 species in two sites.
$ Open : int 350 325 237 102 91 72 68 61 53 50 ...
$ Closed: int 10 55 502 1 3 4 171 140 180 24 ...

Examples

Run this code
  data(Data_spider)

Run the code above in your browser using DataLab